import { h } from 'preact';
import { useContext, useEffect, useState } from 'preact/hooks';
import { route } from 'preact-router';
import AppState, { UserTable } from "../../store";
import api from '../../api'
import { Breadcrumbs } from "../../components";
import { CheckBox, Button, TextBox } from '../../components/controls';
function EditUser({ userid }) {
    let [sessiondata,] = useContext(AppState).session;
    const { usertable, userreducer } = useContext(UserTable);

    const [formdata, formchange] = useState({});
    let maxlength_uid = 10;
    let maxlength_name = 25;
    let maxlength_pin = 10;
    let maxlength_rfid = 8;
    useEffect(() => {
        let user = userid !== undefined ? usertable.find(u => u.uid === userid) : undefined;
        if (user !== undefined) {
            formchange(user);
        }
    }, [userid, usertable]);
    function uidCount(state, user) {
        return state.reduce((pre, curr) => pre + curr.uid == user.uid ? 1 : 0, 0);
    }
    const onReset = (e) => {
        e.preventDefault();
        let user = userid !== undefined ? usertable.find(u => u.uid === userid) : undefined;
        formchange(user !== undefined ? user : {});
    }
    const onSubmit = (e) => {
        e.preventDefault();
        let idcount = uidCount(usertable, formdata);
        console.log(idcount);
        if (formdata.line !== undefined) {
            api.updateUser(sessiondata.token, formdata).then(r => {
                userreducer({ type: 'update', user: r })
            });
            route('/users');
        } else if (idcount === 0) {
            api.createUser(sessiondata.token, formdata).then(r => {
                userreducer({ type: 'create', user: r })
            });
            route('/users');
        }
        else {
            alert(`UID ${formdata.uid} wurde bereits ${idcount} mal benutzt`);
        }
    }
    return (
        <div className='container'>
            <Breadcrumbs items={['Benutzerverwaltung',formdata.line != undefined ? "Benutzer Bearbeiten" : "Neuer Benutzer"]} />
            <div className={'contentbox'} >
                <h2>{formdata.line != undefined ? "Benutzer Bearbeiten" : "Neuer Benutzer"}</h2>
                <form onSubmit={onSubmit}>
                    <h3>Eindeutige Identifikationsnummer</h3>
                    <div className='row'>
                        <div className='column'>
                            <TextBox info={true} formdata={formdata} formchange={formchange} id="uid" label="Benutzer-ID" maxlength={maxlength_uid} />
                            {<span class="textbox__info"> {formdata["uid"]?formdata["uid"].length:0} von {maxlength_uid} Zeichen verwendet.</span>}
                        </div>
                        <div className='column'>
                            <b>Info</b>
                            <span> Nummer muss einmalig sein</span>
                        </div>
                    </div>

                    <h3>Persönliche Daten</h3>
                    <div className='row'>
                        <div className='column'>
                            <TextBox formdata={formdata} formchange={formchange} id="first_name" label="Vorname" maxlength={maxlength_name} />
                            {<span class="textbox__info"> {formdata["first_name"] ?formdata["first_name"].length:0} von {maxlength_name} Zeichen verwendet.</span>}
                        </div>
                        <div className='column'>
                            <TextBox formdata={formdata} formchange={formchange} id="last_name" label="NachName" maxlength={maxlength_name} />
                            {<span class="textbox__info"> {formdata["last_name"]?formdata["last_name"].length:0} von {maxlength_name} Zeichen verwendet.</span>}
                        </div>
                    </div>
                    <h3>Authentifizierung</h3>
                    <div className='row'>
                        <div className='column'>
                            <TextBox formdata={formdata} formchange={formchange} id="rfid_uid" label="RFID" maxlength={maxlength_rfid} />
                            {<span class="textbox__info"> {formdata["rfid_uid"]?formdata["rfid_uid"].length:0} von {maxlength_rfid} Zeichen verwendet.</span>}
                        </div>
                        <div className='column'>
                            <TextBox formdata={formdata} formchange={formchange} id="user_pin" label="Pin" maxlength={maxlength_pin} />
                            {<span class="textbox__info"> {formdata["user_pin"] ?formdata["user_pin"].length:0} von {maxlength_pin} Zeichen verwendet.</span>}
                        </div>
                    </div>
                    <h3>Status</h3>
                    <div className='row'>
                        <div className='column'>
                            <CheckBox formdata={formdata} formchange={formchange} id="enabled" type={'checkbox'} label="Benutzer darf sich anmelden" />
                        </div>

                    </div>
                    <div className='row' style={'justify-content: space-between'}>
                        <div className='column'>
                            <Button onClick={onSubmit} >Speichern</Button>
                        </div>
                        <div className='column'>
                            <Button onClick={onReset} >Zurücksetzen</Button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    )
}
export default EditUser;